NativeElixirPdfUtilities.Validators.WriterValidator (native_elixir_pdf_utilities v0.13.0)
View SourceSemantic validation and normalization for the low-level PDF writer.
Successful preparation returns pages and normalized metadata that the byte writer can serialize without revalidating the page model.
Summary
Functions
Validates pages and writer options and normalizes document metadata.
Types
Functions
@spec prepare(term(), term()) :: {:ok, context()} | {:error, {atom(), NativeElixirPdfUtilities.Diagnostics.diagnostic()}}
Validates pages and writer options and normalizes document metadata.